<?php
/**
 * Perfect Checkout Settings
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Settings
 * @since   1.0.0
 * @version 1.6.11
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Settings' ) ) {

	class Perfect_Checkout_Settings extends Perfect_Checkout_Settings_Page {

		/**
		 * Constructor.
		 *
		 * @access public
		 */
		public function __construct() {
			$this->id    = 'general';
			$this->label = esc_html__( 'Perfect Checkout', 'perfect-checkout' );

			parent::__construct();
		} // END __construct()

		/**
		 * Get array of settings.
		 *
		 * @access public
		 *
		 * @since   1.0.0 Introduced.
		 * @version 1.6.11
		 *
		 * @return array
		 */
		public function get_settings() {
			$pc_license = get_perfect_license();
			$pc_active  = get_option( 'perfectcheckout_set_active', 'no' );

			$connect_url = add_query_arg( array(
				'site' => get_site_url(),
			), PerfectCheckout::get_connect_url() );

			$settings = array();

			if ( empty( $pc_license ) ) {
				$settings[] = array(
					'title' => esc_html__( 'Connect Account', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => sprintf(
						esc_html__( 'Go back to %s to complete the connection with your account.', 'perfect-checkout' ),
						'Perfect Checkout'
					),
					'id'    => 'licence_key',
				);

				$settings[] = array(
					'type'     => 'button',
					'value'    => esc_html__( 'Connect', 'perfect-checkout' ),
					'url'      => $connect_url,
					'class'    => 'button-large perfect-button',
					'id'       => 'perfectcheckout_license',
					'autoload' => false,
				);
			} else {
				if ( ! defined( 'PERFECTCHECKOUT_LICENSE' ) ) {
					$settings[] = array(
						'type' => 'title',
						'id'   => 'licence_key',
					);

					$settings[] = array(
						'title'    => esc_html__( 'License Key', 'perfect-checkout' ),
						'id'       => 'perfectcheckout_license',
						'type'     => 'text',
						'default'  => '',
						'css'      => 'min-width:340px;',
						'class'    => 'required',
						'desc'     => __( 'Note: Your license is good for 1 connected store at a time.', 'perfect-checkout' ),
						'disabled' => true,
						'autoload' => false,
					);

					$disconnect_url = wp_nonce_url( add_query_arg( array(
						'page'          => 'perfect-checkout',
						'pc-disconnect' => true,
					), admin_url( 'admin.php' ) ), 'disconnect-perfectcheckout' );

					$settings[] = array(
						'type'     => 'button',
						'value'    => esc_html__( 'Disconnect', 'perfect-checkout' ),
						'url'      => $disconnect_url,
						'class'    => 'button-large perfect-button',
						'desc'     => __( 'Disconnect if you want to connect to another account.', 'perfect-checkout' ),
						'id'       => 'perfectcheckout_disconnect',
						'autoload' => false,
					);
				}

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'licence_key',
				);
			}

			if ( ! empty( $pc_license ) ) {
				$settings[] = array(
					'title' => sprintf(
						esc_html__( 'Ready for %s?', 'perfect-checkout' ),
						'Perfect Checkout'
					),
					'type'  => 'title',
					'desc'  => esc_html__( 'Press "Activate" when ready to increase your conversion rates.', 'perfect-checkout' ),
					'id'    => 'checkout_page',
				);

				if ( 'yes' === $pc_active ) {
					$switch_checkout_url = wp_nonce_url( add_query_arg( array(
						'page'     => 'perfect-checkout',
						'checkout' => 'default',
					), admin_url( 'admin.php' ) ), 'switch-checkout' );

					$settings[] = array(
						'type'     => 'button',
						'value'    => sprintf(
							/* translators: %s Perfect Checkout */
							esc_html__( 'Disable %s', 'perfect-checkout' ),
							'Perfect Checkout'
						),
						'url'      => $switch_checkout_url,
						'class'    => 'perfect-button',
						'desc'     => sprintf(
							/* translators: %s Perfect Checkout */
							esc_html__( '%s is now handling your cart and checkout needs. ✔️', 'perfect-checkout' ),
							'Perfect Checkout'
						),
						'id'       => 'perfectcheckout_page',
						'autoload' => false,
					);
				} else {
					$switch_checkout_url = wp_nonce_url( add_query_arg( array(
						'page'     => 'perfect-checkout',
						'checkout' => 'perfect',
					), admin_url( 'admin.php' ) ), 'switch-checkout' );

					$settings[] = array(
						'type'     => 'button',
						'value'    => esc_html__( 'Activate', 'perfect-checkout' ),
						'url'      => $switch_checkout_url,
						'class'    => 'perfect-button',
						'id'       => 'perfectcheckout_page',
						'autoload' => false,
					);
				}

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'checkout_page',
				);

				$settings[] = array(
					'title' => esc_html__( 'Google Analytics', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => sprintf(
						esc_html__( 'Enter your Google Analytics tracking ID so Perfect Checkout can help you track customers actions.', 'perfect-checkout' ),
						'Perfect Checkout'
					),
					'id'    => 'google_analytics',
				);

				$settings[] = array(
					'title'       => esc_html__( 'Tracking ID', 'perfect-checkout' ),
					'id'          => 'perfectcheckout_google_analytics',
					'type'        => 'text',
					'default'     => '',
					'css'         => 'width:100%;',
					'desc'        => esc_html__( 'This can be found in your Google Analytics account settings.', 'perfect-checkout' ),
					'placeholder' => 'G-QN6BTJ6W0S',
					'autoload'    => false,
				);

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'google_analytics',
				);

				$settings[] = array(
					'title' => esc_html__( 'Buy Now', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => esc_html__( 'Let your customers checkout instantly by enabling our "Buy Now" buttons.', 'perfect-checkout' ),
					'id'    => 'checkout_now',
				);

				$settings[] = array(
					'title'           => '',
					'desc'            => esc_html__( 'Enable "Buy Now" buttons on shop page.', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_shop_checkout_button',
					'default'         => 'no',
					'type'            => 'checkbox',
					'checkboxgroup'   => 'start',
					'show_if_checked' => 'option',
				);

				$settings[] = array(
					'title'           => '',
					'desc'            => esc_html__( 'Load checkout in modal mode.', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_shop_buy_now_modal',
					'default'         => 'no',
					'type'            => 'checkbox',
					'checkboxgroup'   => '',
					'show_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Button Text', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_shop_buy_now_text',
					'default'         => esc_html__( 'Buy Now', 'perfect-checkout' ),
					'type'            => 'text',
					'placeholder'     => esc_html__( 'Buy Now', 'perfect-checkout' ),
					'checkboxgroup'   => 'end',
					'show_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => '',
					'desc'            => esc_html__( 'Enable "Buy Now" button on product pages.', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_checkout_button',
					'default'         => 'no',
					'type'            => 'checkbox',
					'checkboxgroup'   => 'start',
					'show_if_checked' => 'option',
				);

				$settings[] = array(
					'title'           => '',
					'desc'            => esc_html__( 'Load checkout in modal mode.', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_buy_now_modal',
					'default'         => 'no',
					'type'            => 'checkbox',
					'checkboxgroup'   => '',
					'show_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Button Text', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_buy_now_text',
					'default'         => esc_html__( 'Buy Now', 'perfect-checkout' ),
					'type'            => 'text',
					'placeholder'     => esc_html__( 'Buy Now', 'perfect-checkout' ),
					'checkboxgroup'   => 'end',
					'show_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => '',
					'desc'            => esc_html__( 'Inherit theme style for "Buy Now" buttons.', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_theme_inherit_style',
					'default'         => 'yes',
					'type'            => 'checkbox',
					'checkboxgroup'   => 'start',
					'hide_if_checked' => 'option',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Font Size', 'perfect-checkout' ),
					'desc'            => sprintf( __( 'Enter the font size you wish the "%1$s" button to be in pixels %2$s.', 'perfect-checkout' ), '<strong>' . __( 'Buy Now', 'perfect-checkout' ) . '</strong>', '<strong>(px)</strong>' ),
					'id'              => 'perfectcheckout_buy_now_font_size',
					'default'         => '16',
					'type'            => 'number',
					'min'             => '12',
					'max'             => '24',
					'css'             => 'width:80px;',
					'checkboxgroup'   => '',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Background Color', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_buy_now_bg_color',
					'default'         => '#000000',
					'type'            => 'color',
					'checkboxgroup'   => '',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Text Color', 'perfect-checkout' ),
					'id'              => 'perfectcheckout_buy_now_text_color',
					'default'         => '#ffffff',
					'type'            => 'color',
					'checkboxgroup'   => '',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Padding - Top & Bottom', 'perfect-checkout' ),
					'desc'            => sprintf( __( 'Padding is applied in pixels %s.', 'perfect-checkout' ), '<strong>(px)</strong>' ),
					'id'              => 'perfectcheckout_buy_now_padding',
					'default'         => '15',
					'type'            => 'number',
					'min'             => '0',
					'max'             => '60',
					'css'             => 'width:80px;',
					'checkboxgroup'   => '',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Padding - Left & Right', 'perfect-checkout' ),
					'desc'            => sprintf( __( 'Padding is applied in pixels %s.', 'perfect-checkout' ), '<strong>(px)</strong>' ),
					'id'              => 'perfectcheckout_buy_now_padding_sides',
					'default'         => '60',
					'type'            => 'number',
					'min'             => '0',
					'max'             => '60',
					'css'             => 'width:80px;',
					'checkboxgroup'   => '',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'title'           => esc_html__( 'Border Radius', 'perfect-checkout' ),
					'desc'            => sprintf( __( 'Enter the border radius you wish the "%1$s" button to be in pixels %2$s. Set as 0 to disable.', 'perfect-checkout' ), '<strong>' . __( 'Buy Now', 'perfect-checkout' ) . '</strong>', '<strong>(px)</strong>' ),
					'id'              => 'perfectcheckout_buy_now_border_radius',
					'default'         => '4',
					'type'            => 'number',
					'min'             => '0',
					'max'             => '60',
					'css'             => 'width:80px;',
					'checkboxgroup'   => 'end',
					'hide_if_checked' => 'yes',
				);

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'checkout_now',
				);
			}

			return $settings;
		} // END get_settings()

		/**
		 * Output the settings.
		 *
		 * @access public
		 */
		public function output() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::output_fields( $settings );
		} // END output()

		/**
		 * Save settings.
		 *
		 * @access public
		 */
		public function save() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::save_fields( $settings );
		} // END save()

	} // END class

} // END if class exists

return new Perfect_Checkout_Settings();
