<?php
/**
 * Manages Perfect Checkout assets for the Frontend.
 *
 * @since   1.6.0
 * @author  Sébastien Dumont
 * @package Perfect Checkout
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Assets' ) ) {

	class Perfect_Checkout_Assets {

		/**
		 * Constructor
		 *
		 * @access public
		 */
		public function __construct() {
			add_action( 'wp_head', array( $this, 'add_script_wp_head' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		} // END __construct()

		/**
		 * Adds Perfect Modal to the wp_head.
		 *
		 * @access public
		 */
		public function add_script_wp_head() {
			$shop_modal     = get_option( 'perfectcheckout_shop_buy_now_modal', 'no' );
			$product_modal  = get_option( 'perfectcheckout_buy_now_modal', 'no' );
			$modal_position = 'absolute';

			if ( function_exists( 'is_shop' ) && is_shop() ) {
				$modal_position = 'inherit';
			}

			if ( 'yes' === $shop_modal || 'yes' === $product_modal ) {
				?>
				<script>
				window.addEventListener("load", (event) => {
					// get all open buttons
					var perfButtons = Array.from(document.getElementsByClassName("perf"));

					perfButtons.forEach(function (button, index) {
						button.addEventListener("click", function () {
							var iframeTarget = button.getAttribute("data-perf-target");
							var iframeParent = document.getElementById(iframeTarget);
							var iframeSrc    = button.getAttribute('data-perf-src');

							// create iframe element
							const perfectFrameElement = document.createElement("iframe");
							perfectFrameElement.src = iframeSrc;
							perfectFrameElement.allow = "payment *";
							perfectFrameElement.frameBorder = "0";
							perfectFrameElement.style =
							"width: 100%; height: 100%; border: none; position: <?php echo $modal_position; ?>";
							perfectFrameElement.classList.add("perfectframe");

							console.log({ perfectFrameElement });
							iframeParent.appendChild(perfectFrameElement);
						});
					});

					// get all close buttons
					var perfCloseButtons = Array.from(
						document.getElementsByClassName("btn-close")
					);

					perfCloseButtons.forEach(function (button, index) {
						button.addEventListener("click", function () {
							var perfFrames = Array.from(
								document.getElementsByClassName("perfectframe")
							);

							perfFrames.forEach(function (frame, index) {
								frame.parentNode.removeChild(frame);
							});
						});
					});
				});
				</script>
				<?php
			}
		} // END add_script_wp_head()

		/**
		 * Registers and enqueue Stylesheets and Scripts.
		 *
		 * @access public
		 */
		public function enqueue_scripts() {
			if ( function_exists( 'is_shop' ) && is_shop() || function_exists( 'is_product' ) && is_product() ) {
				$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

				$theme_inherit_style = get_option( 'perfectcheckout_theme_inherit_style', 'yes' );

				wp_register_style( 'perfectcheckout', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/css/perfect-checkout' . $suffix . '.css', array(), PerfectCheckout::$version );
				wp_enqueue_style( 'perfectcheckout' );
				wp_style_add_data( 'perfectcheckout', 'rtl', 'replace' );

				if ( $suffix ) {
					wp_style_add_data( 'perfectcheckout', 'suffix', '.min' );
				}

				$shop_modal    = get_option( 'perfectcheckout_shop_buy_now_modal', 'no' );
				$product_modal = get_option( 'perfectcheckout_buy_now_modal', 'no' );

				if ( 'yes' === $shop_modal || 'yes' === $product_modal ) {
					wp_register_style( 'perfectcheckout-modal', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/css/lib/mdb.min.css', array(), '4.0.0' );
					wp_enqueue_style( 'perfectcheckout-modal' );

					wp_register_script( 'perfectcheckout_modal', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/js/lib/mdb.min.js', array(), '4.0.0', true );
					wp_enqueue_script( 'perfectcheckout_modal' );
				}

				if ( 'yes' !== $theme_inherit_style ) {
					wp_enqueue_style( 'perfectcheckout-font', 'https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap', array(), PerfectCheckout::$version );
				}
			}
		} // END enqueue_scripts()

	} // END class

} // END if class exists

return new Perfect_Checkout_Assets();
