<?php
/**
 * Perfect Checkout Connection Gateway.
 *
 * Emulates the ability of a payment gateway so
 * Perfect Checkout can support the use of saved payment methods.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Gateway
 * @since   1.3.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
	return;
}

class Perfect_Checkout_Gateway_Connection extends WC_Payment_Gateway {

	/**
	 * Constructor for the gateway.
	 */
	public function __construct() {
		// Get settings.
		$this->enabled            = 'yes';
		$this->id                 = 'perfect';
		$this->icon               = '';
		$this->method_title       = __( 'Perfect Checkout', 'perfect-checkout' );
		$this->method_description = __( 'Is enabled always while Perfect Checkout is active to support order processing.', 'perfect-checkout' );
		$this->has_fields         = false;
		$this->supports           = array(
			'products',
			'refunds',
			'tokenization',
			'add_payment_method',
			'subscriptions',
			'subscription_cancellation',
			'subscription_suspension',
			'subscription_reactivation',
			'subscription_amount_changes',
			'subscription_date_changes',
			'subscription_payment_method_change',
			'subscription_payment_method_change_customer',
			'subscription_payment_method_change_admin',
			'multiple_subscriptions',
			'pre-orders',
		);
		$this->title              = 'Perfect Checkout';
		$this->description        = __( 'You can add a new method with your next order. Just remember to tick the checkbox "Save method" to save it.', 'perfect-checkout' );

		// Load the settings.
		$this->init_settings();

		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
	}

	/**
	 * Check If The Gateway Is Available For Use.
	 *
	 * @return bool
	 */
	public function is_available() {
		return true;
	} // END is_available()

	/**
	 * Process the payment and return the result.
	 *
	 * @param int $order_id Order ID.
	 * @return array
	 */
	public function process_payment( $order_id ) {
		$order = wc_get_order( $order_id );

		// Even if somehow triggered, nothing will happen except redirect to the order page.

		// Return thankyou redirect.
		return array(
			'result'   => 'success',
			'redirect' => $this->get_return_url( $order ),
		);
	} // END process_payment()

} // END class
